@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py,v 1.57 2006/08/17 16:15:03 richb Exp $"
-__version__   = "$Revision: 1.57 $"
-__date__      = "$Date: 2006/08/17 16:15:03 $"
+__id__        = "$Id: braillegenerator.py 2223 2007-03-28 17:06:38Z wwalker $"
+__version__   = "$Revision: 2223 $"
+__date__      = "$Date: 2007-03-28 13:06:38 -0400 (Wed, 28 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -37,7 +37,6 @@ import debug
 import orca_state
 import rolenames
 import settings
-import util
 
 from orca_i18n import _                     # for gettext support
 
@@ -47,7 +46,13 @@ class BrailleGenerator:
     primary entry point.  Subclasses can feel free to override/extend
     the brailleGenerators instance field as they see fit."""
 
-    def __init__(self):
+    def __init__(self, script):
+
+        # The script that created us.  This allows us to ask the
+        # script for information if we need it.
+        #
+        self._script = script
+
         self.brailleGenerators = {}
         self.brailleGenerators[rolenames.ROLE_ALERT]               = \
              self._getBrailleRegionsForAlert
@@ -124,7 +129,7 @@ class BrailleGenerator:
         self.brailleGenerators[rolenames.ROLE_TABLE]               = \
              self._getBrailleRegionsForTable
         self.brailleGenerators[rolenames.ROLE_TABLE_CELL]          = \
-             self._getBrailleRegionsForTableCell
+             self._getBrailleRegionsForTableCellRow
         self.brailleGenerators[rolenames.ROLE_TABLE_COLUMN_HEADER] = \
              self._getBrailleRegionsForTableColumnHeader
         self.brailleGenerators[rolenames.ROLE_TABLE_ROW_HEADER]    = \
@@ -159,7 +164,7 @@ class BrailleGenerator:
         if settings.brailleVerbosityLevel == settings.VERBOSITY_LEVEL_VERBOSE:
             text = ""
 
-            result = util.getAcceleratorAndShortcut(obj)
+            result = self._script.getAcceleratorAndShortcut(obj)
 
             accelerator = result[0]
             #shortcut = result[1]
@@ -187,9 +192,10 @@ class BrailleGenerator:
         Returns a string to be displayed.
         """
 
-        if (settings.brailleVerbosityLevel \
-            == settings.VERBOSITY_LEVEL_VERBOSE) \
-            and obj.state.count(atspi.Accessibility.STATE_SENSITIVE) == 0:
+        if obj.state.count(atspi.Accessibility.STATE_SENSITIVE) == 0:
+            # Translators: this represents an item on the screen that has
+            # been set insensitive (or grayed out).
+            #
             return _("grayed")
         else:
             return None
@@ -219,7 +225,11 @@ class BrailleGenerator:
         try:
             minimumIncrement = value.minimumIncrement
         except:
-            minimumIncrement = (value.maximumValue - value.minimumValue) / 100.0
+            minimumIncrement = 0.0
+
+        if minimumIncrement == 0.0:
+            minimumIncrement = (value.maximumValue - value.minimumValue) \
+                               / 100.0
 
         try:
             decimalPlaces = max(0, -math.log10(minimumIncrement))
@@ -285,10 +295,10 @@ class BrailleGenerator:
         regions = []
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, self._getTextForValue(obj))
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, self._getTextForValue(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -324,10 +334,10 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForAnimation", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, self._getTextForRole(obj))
-        text = util.appendString(text, obj.description, ": ")
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, obj.description, ": ")
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -367,15 +377,15 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForCheckBox", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "<x>")
+            text = self._script.appendString(text, "<x>")
         else:
-            text = util.appendString(text, "< >")
+            text = self._script.appendString(text, "< >")
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -397,18 +407,18 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForCheckMenuItem", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "<x>")
+            text = self._script.appendString(text, "<x>")
         else:
-            text = util.appendString(text, "< >")
+            text = self._script.appendString(text, "< >")
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForRole(obj))
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForRole(obj))
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -448,12 +458,12 @@ class BrailleGenerator:
         regions = []
 
         focusedRegionIndex = 0
-        label = util.getDisplayedLabel(obj)
+        label = self._script.getDisplayedLabel(obj)
         if label and (len(label) > 0):
             regions.append(braille.Region(label + " "))
             focusedRegionIndex = 1
 
-        displayedText = util.getDisplayedText(obj)
+        displayedText = self._script.getDisplayedText(obj)
         if displayedText:
             regions.append(braille.Region(displayedText))
 
@@ -467,11 +477,15 @@ class BrailleGenerator:
         #
         if focusedRegionIndex >= len(regions):
             focusedRegionIndex = 0
+        if len(regions) == 0:
+            focusedRegion = None
+        else:
+            focusedRegion = regions[focusedRegionIndex]
 
         # [[[TODO: WDW - perhaps if a text area was created, we should
         # give focus to it.]]]
         #
-        return [regions, regions[focusedRegionIndex]]
+        return [regions, focusedRegion]
 
     def _getBrailleRegionsForDesktopIcon(self, obj):
         """Get the braille for a desktop icon.
@@ -573,15 +587,15 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForIcon", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.image:
             description = obj.image.imageDescription
             if len(description):
-                text = util.appendString(text, description)
+                text = self._script.appendString(text, description)
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -648,13 +662,13 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForMenu", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, rolenames.getBrailleForRoleName(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, rolenames.getBrailleForRoleName(obj))
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -691,12 +705,12 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForMenuItem", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -720,7 +734,7 @@ class BrailleGenerator:
 
         regions = []
 
-        textRegion = braille.Text(obj, util.getDisplayedLabel(obj))
+        textRegion = braille.Text(obj, self._script.getDisplayedLabel(obj))
         regions.append(textRegion)
 
         eol = braille.Region(" $l")
@@ -757,12 +771,12 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForPageTab", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -816,17 +830,17 @@ class BrailleGenerator:
         regions = []
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         # In Java, some push buttons don't have label and text.
         # In this case, we'll add to presentation the object description,
         # if exists.
         #
         if (not text) and (obj.description):
-            text = util.appendString(text, obj.description)
+            text = self._script.appendString(text, obj.description)
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -848,22 +862,22 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForRadioButton", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         # In Java, some toggle buttons don't have label and text.
         # In this case, we'll add to presentation the object description,
         # if exists.
         #
         if (not text) and (obj.description):
-            text = util.appendString(text, obj.description)
+            text = self._script.appendString(text, obj.description)
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "&=y")
+            text = self._script.appendString(text, "&=y")
         else:
-            text = util.appendString(text, "& y")
+            text = self._script.appendString(text, "& y")
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -885,18 +899,18 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForRadioMenuItem", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "&=y")
+            text = self._script.appendString(text, "&=y")
         else:
-            text = util.appendString(text, "& y")
+            text = self._script.appendString(text, "& y")
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForRole(obj))
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForRole(obj))
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -953,11 +967,11 @@ class BrailleGenerator:
         regions = []
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
         # Ignore the text on the slider.
-        #text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, self._getTextForValue(obj))
-        text = util.appendString(text, self._getTextForRole(obj))
+        #text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, self._getTextForValue(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -1009,7 +1023,7 @@ class BrailleGenerator:
         return self._getDefaultBrailleRegions(obj)
 
     def _getBrailleRegionsForTableCell(self, obj):
-        """Get the braille for a table cell
+        """Get the braille for a single table cell
 
         Arguments:
         - obj: the table
@@ -1040,70 +1054,106 @@ class BrailleGenerator:
                     break
 
         if len(regions) == 0:
-            # Adding in a check here to make sure that the parent is a
-            # valid table. It's possible that the parent could be a
-            # table cell too (see bug #351501).
-            #
-            if settings.readTableCellRow and obj.parent.table:
-                rowRegions = []
-                savedBrailleVerbosityLevel = settings.brailleVerbosityLevel
-                settings.brailleVerbosityLevel = \
-                                             settings.VERBOSITY_LEVEL_BRIEF
-
-                parent = obj.parent
-                row = parent.table.getRowAtIndex(obj.index)
-                column = parent.table.getColumnAtIndex(obj.index)
-
-                # This is an indication of whether we should speak all the
-                # table cells (the user has moved focus up or down a row),
-                # or just the current one (focus has moved left or right in
-                # the same row).
-                #
-                speakAll = True
-                if parent.__dict__.has_key("lastRow") and \
-                    parent.__dict__.has_key("lastColumn"):
-                    speakAll = (parent.lastRow != row) or \
-                           ((row == 0 or row == parent.table.nRows-1) and \
-                            parent.lastColumn == column)
-
-                if speakAll:
-                    focusRowRegion = None
-                    for i in range(0, parent.table.nColumns):
-                        accRow = parent.table.getAccessibleAt(row, i)
-                        cell = atspi.Accessible.makeAccessible(accRow)
-                        [cellRegions, focusRegion] = \
-                            self._getDefaultBrailleRegions(\
-                                util.getRealActiveDescendant(cell))
-                        if len(rowRegions):
-                            rowRegions.append(braille.Region(" "))
-                        rowRegions.append(cellRegions[0])
-                        if i == column:
-                            focusRowRegion = cellRegions[0]
-                    regions = [rowRegions, focusRowRegion]
-                    settings.brailleVerbosityLevel = savedBrailleVerbosityLevel
-                else:
-                    regions = self._getDefaultBrailleRegions(
-                        util.getRealActiveDescendant(obj))
-            else:
-                regions = self._getDefaultBrailleRegions(
-                    util.getRealActiveDescendant(obj))
+            regions = self._getDefaultBrailleRegions(
+                              self._script.getRealActiveDescendant(obj))
+        else:
+            [cellRegions, focusRegion] = self._getDefaultBrailleRegions(\
+                self._script.getRealActiveDescendant(obj))
+            regions[0].extend(cellRegions)
 
         # [[[TODO: WDW - HACK attempt to determine if this is a node;
         # if so, describe its state.]]]
         #
         if obj.state.count(atspi.Accessibility.STATE_EXPANDABLE):
             if obj.state.count(atspi.Accessibility.STATE_EXPANDED):
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
                 regions[0].append(braille.Region(" " + _("expanded")))
             else:
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
                 regions[0].append(braille.Region(" " + _("collapsed")))
 
-        level = util.getNodeLevel(obj)
+        level = self._script.getNodeLevel(obj)
         if level >= 0:
+            # Translators: this represents the depth of a node in a tree
+            # view (i.e., how many ancestors a node has).
+            #
             regions[0].append(braille.Region(" " + _("TREE LEVEL %d") \
                                              % (level + 1)))
 
         return regions
 
+    def _getBrailleRegionsForTableCellRow(self, obj):
+        """Get the braille for a table cell row or a single table cell
+        if settings.readTableCellRow is False.
+
+        Arguments:
+        - obj: the table
+
+        Returns a list where the first element is a list of Regions to display
+        and the second element is the Region which should get focus.
+        """
+
+        self._debugGenerator("_getBrailleRegionsForTableColumnHeader", obj)
+
+        regions = []
+
+        # Adding in a check here to make sure that the parent is a
+        # valid table. It's possible that the parent could be a
+        # table cell too (see bug #351501).
+        #
+        if settings.readTableCellRow and obj.parent.table \
+            and (not self._script.isLayoutOnly(obj.parent)):
+            rowRegions = []
+            savedBrailleVerbosityLevel = settings.brailleVerbosityLevel
+            settings.brailleVerbosityLevel = \
+                                         settings.VERBOSITY_LEVEL_BRIEF
+
+            parent = obj.parent
+            row = parent.table.getRowAtIndex(obj.index)
+            column = parent.table.getColumnAtIndex(obj.index)
+
+            # This is an indication of whether we should speak all the
+            # table cells (the user has moved focus up or down a row),
+            # or just the current one (focus has moved left or right in
+            # the same row).
+            #
+            speakAll = True
+            if parent.__dict__.has_key("lastRow") and \
+                parent.__dict__.has_key("lastColumn"):
+                speakAll = (parent.lastRow != row) or \
+                       ((row == 0 or row == parent.table.nRows-1) and \
+                        parent.lastColumn == column)
+
+            if speakAll:
+                focusRowRegion = None
+                for i in range(0, parent.table.nColumns):
+                    accRow = parent.table.getAccessibleAt(row, i)
+                    cell = atspi.Accessible.makeAccessible(accRow)
+                    showing = cell.state.count( \
+                                    atspi.Accessibility.STATE_SHOWING)
+                    if showing:
+                        [cellRegions, focusRegion] = \
+                            self._getBrailleRegionsForTableCell(cell)
+                        if len(rowRegions):
+                            rowRegions.append(braille.Region(" "))
+                        rowRegions.append(cellRegions[0])
+                        if i == column:
+                            focusRowRegion = cellRegions[0]
+                regions = [rowRegions, focusRowRegion]
+                settings.brailleVerbosityLevel = savedBrailleVerbosityLevel
+            else:
+                regions = self._getBrailleRegionsForTableCell(obj)
+        else:
+            regions = self._getBrailleRegionsForTableCell(obj)
+
+        return regions
+
     def _getBrailleRegionsForTableColumnHeader(self, obj):
         """Get the braille for a table column header
 
@@ -1162,14 +1212,14 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForTerminal", obj)
 
         title = None
-        frame = util.getFrame(obj)
+        frame = self._script.getFrame(obj)
         if frame:
             title = frame.name
         if not title:
-            title = util.getDisplayedLabel(obj)
+            title = self._script.getDisplayedLabel(obj)
 
         text = title
-        text = util.appendString(text, rolenames.getBrailleForRoleName(obj))
+        text = self._script.appendString(text, rolenames.getBrailleForRoleName(obj))
 
         regions = []
         regions.append(braille.Region(text))
@@ -1365,17 +1415,17 @@ class BrailleGenerator:
             # as bugzilla bug 319751.]]]
             #
             if (parent.role != rolenames.ROLE_FILLER) \
-                and (parent.role != rolenames.ROLE_SPLIT_PANE):
+                and (parent.role != rolenames.ROLE_SECTION) \
+                and (parent.role != rolenames.ROLE_SPLIT_PANE) \
+                and (not self._script.isLayoutOnly(parent)):
 
                 # Announce the label and text of the object in the hierarchy.
                 #
-                label = util.getDisplayedLabel(parent)
-                text = util.getDisplayedText(parent)
-                if ((label and len(label)) or (text and len(text))) \
-                    or (parent.role != rolenames.ROLE_PANEL):
-                    regions.append(braille.Region(" "))
-                    result = self.getBrailleRegions(parent, False)
-                    regions.extend(result[0])
+                label = self._script.getDisplayedLabel(parent)
+                text = self._script.getDisplayedText(parent)
+                regions.append(braille.Region(" "))
+                result = self.getBrailleRegions(parent, False)
+                regions.extend(result[0])
 
             # [[[TODO: HACK - we've discovered oddness in hierarchies
             # such as the gedit Edit->Preferences dialog.  In this
@@ -1386,7 +1436,7 @@ class BrailleGenerator:
             # we add the label to the overall context.]]]
             #
             if parent.role == rolenames.ROLE_FILLER:
-                label = util.getDisplayedLabel(parent)
+                label = self._script.getDisplayedLabel(parent)
                 if label and len(label) and not label.isspace():
                     regions.append(braille.Region(" "))
                     result = self.getBrailleRegions(parent, False)
