@@ -19,9 +19,9 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 2090 2007-03-04 23:08:20Z wwalker $"
-__version__   = "$Revision: 2090 $"
-__date__      = "$Date: 2007-03-04 18:08:20 -0500 (Sun, 04 Mar 2007) $"
+__id__        = "$Id: flat_review.py 2126 2007-03-06 21:35:17Z richb $"
+__version__   = "$Revision: 2126 $"
+__date__      = "$Date: 2007-03-06 16:35:17 -0500 (Tue, 06 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -34,7 +34,6 @@ import debug
 import eventsynthesizer
 import orca_state
 import rolenames
-import util
 
 # [[[WDW - HACK Regular expression to split strings on whitespace
 # boundaries, which is what we'll use for word dividers instead of
@@ -401,7 +400,8 @@ class Context:
 
         if orca_state.locusOfFocus and \
            orca_state.locusOfFocus.role == rolenames.ROLE_TABLE_CELL:
-            searchZone = util.getRealActiveDescendant(orca_state.locusOfFocus)
+            searchZone = orca_state.activeScript.getRealActiveDescendant(\
+                                                   orca_state.locusOfFocus)
         else:
             searchZone = orca_state.locusOfFocus
 
@@ -572,7 +572,7 @@ class Context:
         #print "LOOKING AT '%s'" % unicodeString
         for i in range(0, len(unicodeString) + 1):
             if (i != len(unicodeString)) \
-               and (unicodeString[i] != util.EMBEDDED_OBJECT_CHARACTER):
+               and (unicodeString[i] != orca_state.activeScript.EMBEDDED_OBJECT_CHARACTER):
                 substringEndOffset += 1
             elif (substringEndOffset == substringStartOffset):
                 substringStartOffset += 1
@@ -666,7 +666,7 @@ class Context:
             #      % (offset, startOffset, endOffset, string)
             #if startOffset > offset:
             #    embedded = text.getText(offset, offset + 1).decode("UTF-8")
-            #    if embedded[0] == util.EMBEDDED_OBJECT_CHARACTER:
+            #    if embedded[0] == orca_state.activeScript.EMBEDDED_OBJECT_CHARACTER:
             #        offset = startOffset
 
             debug.println(debug.LEVEL_FINEST,
