@@ -19,9 +19,9 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 2209 2007-03-28 00:05:34Z wwalker $"
-__version__   = "$Revision: 2209 $"
-__date__      = "$Date: 2007-03-27 20:05:34 -0400 (Tue, 27 Mar 2007) $"
+__id__        = "$Id: orca.py 2298 2007-04-18 18:40:05Z wwalker $"
+__version__   = "$Revision: 2298 $"
+__date__      = "$Date: 2007-04-18 14:40:05 -0400 (Wed, 18 Apr 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -63,8 +63,6 @@ import rolenames
 import settings
 import speech
 
-import threading
-
 from input_event import BrailleEvent
 from input_event import KeyboardEvent
 from input_event import MouseButtonEvent
@@ -227,7 +225,7 @@ def _onChildrenChanged(e):
         #
         try:
             if registry.desktop.childCount == 0:
-                speech.speak(_("User logged out - shutting down."))
+                speech.speak(_("Goodbye."))
                 shutdown()
                 return
         except: # could be a CORBA.COMM_FAILURE
@@ -355,15 +353,6 @@ def toggleKeystrokeRecording(script=None, inputEvent=None):
 #                                                                      #
 ########################################################################
 
-def cycleDebugLevel(script=None, inputEvent=None):
-    """Cycles the debug level at run time.
-
-    Arguments:
-    - inputEvent: the InputEvent instance that caused this to be called.
-
-    Returns True indicating the event should be consumed.
-    """
-
 def cycleDebugLevel(script=None, inputEvent=None):
     global _debugLevel
 
@@ -391,13 +380,13 @@ def cycleDebugLevel(script=None, inputEvent=None):
     debug.debugLevel = level
 
     if level == debug.LEVEL_ALL:
-        speech.speak(_("Debug level all."))
+        speech.speak("Debug level all.")
     elif level == debug.LEVEL_FINEST:
-        speech.speak(_("Debug level finest."))
+        speech.speak("Debug level finest.")
     elif level == debug.LEVEL_FINER:
-        speech.speak(_("Debug level finer."))
+        speech.speak("Debug level finer.")
     elif level == debug.LEVEL_FINE:
-        speech.speak(("Debug level fine."))
+        speech.speak("Debug level fine.")
     elif level == debug.LEVEL_CONFIGURATION:
         speech.speak("Debug level configuration.")
     elif level == debug.LEVEL_INFO:
@@ -574,22 +563,22 @@ def _keyEcho(event):
                 return
 
             modifiers = event.modifiers
-            if event_string == _("Caps_Lock"):
+            if event_string == "Caps_Lock":
                 if modifiers & (1 << atspi.Accessibility.MODIFIER_SHIFTLOCK):
-                    lockState = _(" off")
+                    lockState = " " + _("off")
                 else:
-                    lockState = _(" on")
+                    lockState = " " + _("on")
 
-            elif event_string == _("Num_Lock"):
+            elif event_string == "Num_Lock":
                 # [[[TODO: richb - we are not getting a correct modifier
                 # state value returned when Num Lock is turned off.
                 # Commenting out the speaking of the bogus on/off state
                 # until this can be fixed.]]]
                 #
                 #if modifiers & (1 << atspi.Accessibility.MODIFIER_NUMLOCK):
-                #    event_string += _(" off")
+                #    event_string += " " + _("off")
                 #else:
-                #    event_string += _(" on")
+                #    event_string += " " + _("on")
                 pass
 
         elif _isFunctionKey(event_string):
@@ -635,6 +624,10 @@ def _processKeyCaptured(event):
         elif event.event_string == "Escape":
             orca_state.capturingKeys = False
         else:
+            # Translators: this is a spoken prompt letting the user know
+            # Orca has recorded a new key combination (e.g., Alt+Ctrl+g)
+            # based upon their input.
+            #
             speech.speak(_("Key captured: %s. Press enter to confirm.") \
                          % str(event.event_string))
             orca_state.lastCapturedKey = event
@@ -700,7 +693,9 @@ def _processKeyboardEvent(event):
         _orcaModifierPressed = False
 
     if _orcaModifierPressed:
-        keyboardEvent.modifiers |= (1 << settings.MODIFIER_ORCA)
+        keyboardEvent.modifiers = keyboardEvent.modifiers \
+                                  | (1 << settings.MODIFIER_ORCA)
+
 
     # Orca gets first stab at the event.  Then, the presenter gets
     # a shot. [[[TODO: WDW - might want to let the presenter try first?
@@ -792,8 +787,14 @@ def _toggleSilenceSpeech(script=None, inputEvent=None):
     speech.stop()
     if settings.silenceSpeech:
         settings.silenceSpeech = False
+        # Translators: this is a spoken prompt letting the user know
+        # that speech synthesis has been turned back on.
+        #
         speech.speak(_("Speech enabled."))
     else:
+        # Translators: this is a spoken prompt letting the user know
+        # that speech synthesis has been temporarily turned off.
+        #
         speech.speak(_("Speech disabled."))
         settings.silenceSpeech = True
     return True
@@ -842,6 +843,10 @@ def loadUserSettings(script=None, inputEvent=None):
         try:
             speech.init()
             if reloaded:
+                # Translators: there is a keystroke to reload the user
+                # preferences.  This is a spoken prompt to let the user
+                # know when the preferences has been reloaded.
+                #
                 speech.speak(_("Orca user settings reloaded."))
             debug.println(debug.LEVEL_CONFIGURATION,
                           "Speech module has been initialized.")
@@ -946,21 +951,25 @@ def _showPreferencesConsole(script=None, inputEvent=None):
 
     return True
 
-def _showQuitGUI(script=None, inputEvent=None):
-    """Displays the user interace to quit Orca.
+def quitOrca(script=None, inputEvent=None):
+    """Quit Orca. Check if the user wants to confirm this action.
+    If so, show the confirmation GUI otherwise just shutdown.
 
     Returns True to indicate the input event has been consumed.
     """
 
-    try:
-        module = __import__(settings.quitModule,
-                            globals(),
-                            locals(),
-                            [''])
-        module.showQuitUI()
-    except:
-        debug.printException(debug.LEVEL_SEVERE)
-        pass
+    if settings.quitOrcaNoConfirmation:
+        shutdown()
+    else:
+        try:
+            module = __import__(settings.quitModule,
+                                globals(),
+                                locals(),
+                                [''])
+            module.showQuitUI()
+        except:
+            debug.printException(debug.LEVEL_SEVERE)
+            pass
 
     return True
 
@@ -1086,7 +1095,9 @@ def shutdown(script=None, inputEvent=None):
         signal.signal(signal.SIGALRM, settings.timeoutCallback)
         signal.alarm(settings.timeoutTime)
 
-    speech.speak(_("goodbye."))
+    # Translators: this is what Orca speaks and brailles when it quits.
+    #
+    speech.speak(_("Goodbye."))
     braille.displayMessage(_("Goodbye."))
 
     # Deregister our event listeners
@@ -1169,21 +1180,21 @@ def abortOnSignal(signum, frame):
 
 def usage():
     """Prints out usage information."""
-    print _("Usage: orca [OPTION...]")
+    print "Usage: orca [OPTION...]"
     print
-    print _("-?, --help                   Show this help message")
-    print _("-v, --version                %s") % platform.version
-    print _("-s, --setup, --gui-setup     Set up user preferences")
-    print _("-t, --text-setup             Set up user preferences (text version)")
-    print _("-n, --no-setup               Skip set up of user preferences")
-    print _("-u, --user-prefs-dir=dirname Use alternate directory for user preferences")
-    print _("-e, --enable=[speech|braille|braille-monitor|magnifier|main-window] Force use of option")
-    print _("-d, --disable=[speech|braille|braille-monitor|magnifier|main-window] Prevent use of option")
-    print _("-q, --quit                   Quits Orca (if shell script used)")
+    print "-?, --help                   Show this help message"
+    print "-v, --version                %s" % platform.version
+    print "-s, --setup, --gui-setup     Set up user preferences"
+    print "-t, --text-setup             Set up user preferences (text version)"
+    print "-n, --no-setup               Skip set up of user preferences"
+    print "-u, --user-prefs-dir=dirname Use alternate directory for user preferences"
+    print "-e, --enable=[speech|braille|braille-monitor|magnifier|main-window] Force use of option"
+    print "-d, --disable=[speech|braille|braille-monitor|magnifier|main-window] Prevent use of option"
+    print "-q, --quit                   Quits Orca (if shell script used)"
     print
-    print _("If Orca has not been previously set up by the user, Orca\nwill automatically launch the preferences set up unless\nthe -n or --no-setup option is used.")
+    print "If Orca has not been previously set up by the user, Orca\nwill automatically launch the preferences set up unless\nthe -n or --no-setup option is used."
     print
-    print _("Report bugs to orca-list@gnome.org.")
+    print "Report bugs to orca-list@gnome.org."
     pass
 
 def main():
@@ -1212,7 +1223,6 @@ def main():
     #
     desktopRunning = False
     try:
-        import gtk
         if gtk.gdk.display_get_default():
             desktopRunning = True
     except:
@@ -1328,10 +1338,8 @@ def main():
     # setting is typically not set since the gdm user does not
     # have a home.
     #
-    import commands
-    a11yEnabled = commands.getoutput(\
-        "gconftool-2 --get /desktop/gnome/interface/accessibility")
-    if (not bypassSetup) and (a11yEnabled != "true"):
+    a11yEnabled = settings.isAccessibilityEnabled()
+    if (not bypassSetup) and (not a11yEnabled):
         _showPreferencesConsole()
         abort()
 
