@@ -19,9 +19,9 @@
 
 """Provides a custom script for gcalctool."""
 
-__id__        = "$Id: gcalctool.py 1658 2006-11-03 21:18:21Z richb $"
-__version__   = "$Revision: 1658 $"
-__date__      = "$Date: 2006-11-03 16:18:21 -0500 (Fri, 03 Nov 2006) $"
+__id__        = "$Id: gcalctool.py 2141 2007-03-07 21:00:32Z richb $"
+__version__   = "$Revision: 2141 $"
+__date__      = "$Date: 2007-03-07 16:00:32 -0500 (Wed, 07 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -33,7 +33,6 @@ import orca.orca_state as orca_state
 import orca.rolenames as rolenames
 import orca.speech as speech
 import orca.speechgenerator as speechgenerator
-import orca.util as util
 
 ########################################################################
 #                                                                      #
@@ -61,7 +60,7 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
         if obj.name:
             name = obj.name
         else:
-            name = util.getDisplayedText(obj)
+            name = self._script.getDisplayedText(obj)
 
         if name:
             return [name]
@@ -114,9 +113,9 @@ class Script(default.Script):
             # the text_view display. This can be found by looking for an
             # accessible object with a role of ROLE_EDITBAR.
             #
-            d = util.findByRole(event.source, rolenames.ROLE_TEXT)
+            d = self.findByRole(event.source, rolenames.ROLE_TEXT)
             if len(d) == 0:
-                d = util.findByRole(event.source, rolenames.ROLE_EDITBAR)
+                d = self.findByRole(event.source, rolenames.ROLE_EDITBAR)
 
             # If d is an empty list at this point, we're unable to get the
             # gcalctool display. Inform the user.
