@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 
 """Custom script for gedit."""
 
-__id__        = "$Id: gedit.py 2140 2007-03-07 20:04:06Z richb $"
-__version__   = "$Revision: 2140 $"
-__date__      = "$Date: 2007-03-07 15:04:06 -0500 (Wed, 07 Mar 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: gedit.py 2289 2007-04-17 15:27:48Z richb $"
+__version__   = "$Revision: 2289 $"
+__date__      = "$Date: 2007-04-17 11:27:48 -0400 (Tue, 17 Apr 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import orca.debug as debug
@@ -32,8 +32,10 @@ import orca.default as default
 import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.rolenames as rolenames
+import orca.settings as settings
 import orca.speech as speech
 import orca.speechgenerator as speechgenerator
+import orca.speechserver as speechserver
 
 from orca.orca_i18n import _
 
@@ -109,6 +111,128 @@ class Script(default.Script):
         """
         return SpeechGenerator(self)
 
+    def __sayAllProgressCallback(self, context, type):
+        """Provide feedback during the sayAll operation.
+        """
+
+        if type == speechserver.SayAllContext.PROGRESS:
+            #print "PROGRESS", context.utterance, context.currentOffset
+            pass
+        elif type == speechserver.SayAllContext.INTERRUPTED:
+            #print "INTERRUPTED", context.utterance, context.currentOffset
+            offset = context.currentOffset
+            for i in range(0, len(context.obj)):
+                obj = context.obj[i]
+                charCount = obj.text.characterCount
+                if offset > charCount:
+                    offset -= charCount
+                else:
+                    obj.text.setCaretOffset(offset)
+                    break
+        elif type == speechserver.SayAllContext.COMPLETED:
+            #print "COMPLETED", context.utterance, context.currentOffset
+            obj = context.obj[len(context.obj)-1]
+            obj.text.setCaretOffset(context.currentOffset)
+            orca.setLocusOfFocus(None, obj, False)
+
+    def textLines(self, obj):
+        """Creates a generator that can be used to iterate over each line
+        of a text object, starting at the caret offset.
+
+        Arguments:
+        - obj: an Accessible that has a text specialization
+
+        Returns an iterator that produces elements of the form:
+        [SayAllContext, acss], where SayAllContext has the text to be
+        spoken and acss is an ACSS instance for speaking the text.
+        """
+        if not obj:
+            return
+
+        text = obj.text
+        if not text:
+            return
+
+        length = text.characterCount
+        offset = text.caretOffset
+        string = ""
+        textObjs = []
+        textObjs.append(obj)
+        startOffset = obj.text.caretOffset
+
+        # Determine the correct "say all by" mode to use.
+        #        
+        if settings.sayAllStyle == settings.SAYALL_STYLE_SENTENCE:
+            mode = atspi.Accessibility.TEXT_BOUNDARY_SENTENCE_END
+        elif settings.sayAllStyle == settings.SAYALL_STYLE_LINE:
+            mode = atspi.Accessibility.TEXT_BOUNDARY_LINE_START
+        else:
+            mode = atspi.Accessibility.TEXT_BOUNDARY_LINE_START
+
+        # Get the next line of text to read
+        #
+        done = False
+        while not done:
+            lastEndOffset = -1
+            while offset < length:
+                [mystr, start, end] = text.getTextAtOffset(offset, mode)
+
+                if len(mystr) != 0:
+                    string += mystr
+
+                if mode == atspi.Accessibility.TEXT_BOUNDARY_LINE_START or \
+                   len(mystr) == 0 or mystr[len(mystr)-1] in '.?!':
+                    endOffset = end
+
+                    string = self.adjustForRepeats(string)
+                    if string.isupper():
+                        voice = settings.voices[settings.UPPERCASE_VOICE]
+                    else:
+                        voice = settings.voices[settings.DEFAULT_VOICE]
+
+                    yield [speechserver.SayAllContext(textObjs, string,
+                                                      startOffset, endOffset),
+                           voice]
+                    string = ""
+                    startOffset = endOffset
+
+                if len(mystr) == 0:
+                    break
+                else:
+                    offset = end
+
+            moreLines = False
+            relations = obj.relations
+            for relation in relations:
+                if relation.getRelationType()  \
+                       == atspi.Accessibility.RELATION_FLOWS_TO:
+                    obj = atspi.Accessible.makeAccessible(relation.getTarget(0))
+
+                    text = obj.text
+                    if not text:
+                        return
+
+                    textObjs.append(obj)
+                    length = text.characterCount
+                    offset = 0
+                    moreLines = True
+                    break
+            if not moreLines:
+                done = True
+
+        # If there is anything left unspoken, speak it now.
+        #
+        if len(string) != 0:
+            string = self.adjustForRepeats(string)
+            if string.isupper():
+                voice = settings.voices[settings.UPPERCASE_VOICE]
+            else:
+                voice = settings.voices[settings.DEFAULT_VOICE]
+
+            yield [speechserver.SayAllContext(textObjs, string,
+                                              startOffset, endOffset),
+                   voice]
+
     def readMisspeltWord(self, event, panel):
         """Speak/braille the current misspelt word plus its context.
            The spell check dialog contains a "paragraph" which shows the
@@ -134,6 +258,11 @@ class Script(default.Script):
         #
         allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
         for label in allLabels:
+            # Translators: these are labels from the gedit spell checking
+            # dialog and must be the same strings gedit uses.  We hate
+            # keying off stuff like this, but we're forced to do so in
+            # in this case.
+            #
             if label.name.startswith(_("Change to:")) or \
                label.name.startswith(_("Misspelled word:")):
                 continue
@@ -163,7 +292,11 @@ class Script(default.Script):
             # The indication that spell checking is complete is when the
             # "misspelt" word is set to "Completed spell checking". Ugh!
             # Try to detect this and let the user know.
-
+            #
+            # Translators: this string must be the same that is used by
+            # gedit.  We hate keying off stuff like this, but we're
+            # forced to do so in this case.
+            #
             if badWord == _("Completed spell checking"):
                 utterance = _("Spell checking is complete.")
                 speech.speak(utterance)
@@ -209,6 +342,11 @@ class Script(default.Script):
                      rolenames.ROLE_DIALOG,
                      rolenames.ROLE_APPLICATION]
 
+        # Translators: this is used to tell us if the focus is on the
+        # "Find" button in gedit's Find dialog.  It must match what
+        # gedit is using.  We hate keying off stuff like this, but
+        # we're forced to do so in this case.
+        #
         if (self.isDesiredFocusedItem(obj, rolesList1) \
             and obj.name == _("Find")) \
             or (self.isDesiredFocusedItem(obj, rolesList2) \
@@ -281,6 +419,11 @@ class Script(default.Script):
                      rolenames.ROLE_FRAME]
         if self.isDesiredFocusedItem(event.source, rolesList):
             frame = event.source.parent.parent.parent.parent
+            # Translators: this is the name of the "Check Spelling" window
+            # in gedit and must be the same as what gedit uses.  We hate
+            # keying off stuff like this, but we're forced to do so in this
+            # case.
+            #
             if frame.name.startswith(_("Check Spelling")):
                 debug.println(self.debugLevel,
                         "gedit.locusOfFocusChanged - check spelling dialog.")
@@ -335,6 +478,11 @@ class Script(default.Script):
                      rolenames.ROLE_FRAME]
         if self.isDesiredFocusedItem(event.source, rolesList):
             frame = event.source.parent.parent.parent
+            # Translators: this is the name of the "Check Spelling" window
+            # in gedit and must be the same as what gedit uses.  We hate
+            # keying off stuff like this, but we're forced to do so in this
+            # case.
+            #
             if frame.name.startswith(_("Check Spelling")):
                 debug.println(self.debugLevel,
                       "gedit.onNameChanged - check spelling dialog.")
@@ -354,6 +502,11 @@ class Script(default.Script):
         # apparently get two identical "object:property-change:accessible-name"
         # events.]]]
 
+        # Translators: the "Phrase not found" is the result of a failed
+        # find command.  It must be the same as what gedit uses.  We hate
+        # keying off stuff like this, but we're forced to do so in this
+        # case.
+        #
         if event.source.role == rolenames.ROLE_STATUSBAR \
            and self.isFocusOnFindDialog() \
            and orca_state.lastInputEvent.event_string == "Return" \
@@ -420,6 +573,9 @@ class Script(default.Script):
             [text, caretOffset, startOffset] = \
                 self.getTextLineAtCaret(event.source)
             if text.lower().find(phrase) != -1:
+                # Translators: this indicates a find command succeeded in
+                # finding something.
+                #
                 speech.speak(_("Phrase found."))
                 utterances = self.speechGenerator.getSpeech(event.source, True)
                 speech.speakUtterances(utterances)
