@@ -19,9 +19,9 @@
 
 """Custom script for users-admin"""
 
-__id__        = "$Id: users-admin.py 2126 2007-03-06 21:35:17Z richb $"
-__version__   = "$Revision: 2126 $"
-__date__      = "$Date: 2007-03-06 16:35:17 -0500 (Tue, 06 Mar 2007) $"
+__id__        = "$Id: users-admin.py 2281 2007-04-11 23:57:58Z wwalker $"
+__version__   = "$Revision: 2281 $"
+__date__      = "$Date: 2007-04-11 19:57:58 -0400 (Wed, 11 Apr 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -127,7 +127,7 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
                 i -= 1
         else:
             utterances = speechGen._getSpeechForTableCell(self, \
-                           self.getRealActiveDescendant(obj), already_focused)
+                self._script.getRealActiveDescendant(obj), already_focused)
 
         return utterances
 
