@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -21,20 +21,23 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 2169 2007-03-13 15:28:45Z wwalker $"
-__version__   = "$Revision: 2169 $"
-__date__      = "$Date: 2007-03-13 11:28:45 -0400 (Tue, 13 Mar 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: settings.py 2292 2007-04-17 22:04:51Z wwalker $"
+__version__   = "$Revision: 2292 $"
+__date__      = "$Date: 2007-04-17 18:04:51 -0400 (Tue, 17 Apr 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import os
 import re
-import sys
 
 screenWidth = 640
 screenHeight = 480
 tty = 7
 
+# Whether tool tips can be presented.
+#
+presentToolTips = False
+
 try:
     # This can fail due to gtk not being available.  We want to
     # be able to recover from that if possible.  The main driver
@@ -56,9 +59,24 @@ try:
     #
     (atom, format, data) = _root_window.property_get("XFree86_VT")
     tty = data[0]
+
+    # The bug that caused gnome-panel to crash is fixed in GTK 2.10.11.
+    minimum_gtk_version = (100000 * 2) + \
+                          (1000 * 10) + \
+                           11
+    current_gtk_version  = (100000 * gtk.gtk_version[0]) + \
+                           (1000 * gtk.gtk_version[1]) + \
+                            gtk.gtk_version[2]
+    presentToolTips = (current_gtk_version >= minimum_gtk_version)
 except:
     pass
 
+try:
+    import gconf
+    gconfClient = gconf.client_get_default()
+except:
+    gconfClient = None
+
 import debug
 from acss import ACSS
 from orca_i18n import _           # for gettext support
@@ -106,6 +124,8 @@ userCustomizableSettings = [
     "magTargetDisplay",
     "verbalizePunctuationStyle",
     "showMainWindow",
+    "quitOrcaNoConfirmation",
+    "sayAllStyle",
     "keyboardLayout",
     "speakBlankLines",
 ]
@@ -174,6 +194,12 @@ PUNCTUATION_STYLE_MOST = 1
 PUNCTUATION_STYLE_ALL  = 0
 verbalizePunctuationStyle = PUNCTUATION_STYLE_MOST
 
+# Say All styles (see sayAllStyle).
+#
+SAYALL_STYLE_LINE     = 0
+SAYALL_STYLE_SENTENCE = 1
+sayAllStyle = SAYALL_STYLE_SENTENCE
+
 # The absolue amount to change the speech rate when
 # increasing or decreasing speech.  This is a numerical
 # value that represents an ACSS rate value.
@@ -314,7 +340,7 @@ enableEchoByWord        = False
 # Note that it is allowable for both enableEchoByWord and enableKeyEcho
 # to be True
 #
-enableKeyEcho           = False
+enableKeyEcho           = True
 
 # If True and key echo is enabled, echo Alphanumeric and punctuation keys.
 #
@@ -340,6 +366,11 @@ enableActionKeys        = True
 #
 showMainWindow          = True
 
+# If True, quit Orca without confirmation when the user presses
+# <Orca-modifier>-q.
+#
+quitOrcaNoConfirmation  = False
+
 # Keyboard layout options (see keyboardLayout).
 #
 GENERAL_KEYBOARD_LAYOUT_DESKTOP = 1
@@ -453,6 +484,38 @@ timeoutCallback         = None # Set by orca.py:init to orca.timeout
 #
 doubleClickTimeout = 0.5
 
+# Obtain/set information regarding whether accessibility is enabled
+# or not.
+#
+def isAccessibilityEnabled():
+    try:
+        return gconfClient.get_bool("/desktop/gnome/interface/accessibility")
+    except:
+        return False
+
+def setAccessibilityEnabled(enable):
+    try:
+        return gconfClient.set_bool("/desktop/gnome/interface/accessibility",
+                                    enable)
+    except:
+        return False
+
+# Obtain/set information regarding whether the gksu keyboard grab is enabled
+# or not.
+#
+def isGKSUGrabDisabled():
+    try:
+        return gconfClient.get_bool("/apps/gksu/disable-grab")
+    except:
+        return False
+
+def setGKSUGrabDisabled(disable):
+    try:
+        return gconfClient.set_bool("/apps/gksu/disable-grab",
+                                    disable)
+    except:
+        return False
+
 # Allow for the customization of key bindings.
 #
 def overrideKeyBindings(script, keyBindings):
@@ -521,22 +584,66 @@ def getScriptModuleName(app):
 
     return app.name
 
-# Note to translators: the regular expression here represents a
-# string to match in the localized application name as seen by
-# at-poke.  For most cases, the application name is the name of
-# the binary used to start the application, but this is an
-# unreliable assumption.  The only reliable way to do the
-# translation is by running the application and then viewing its
-# name in the main window of at-poke.
+# Translators: the regular expression here represents a string to
+# match in the localized application name as seen by at-poke.  For
+# most cases, the application name is the name of the binary used to
+# start the application, but this is an unreliable assumption.  The
+# only reliable way to do the translation is by running the
+# application and then viewing its name in the main window of at-poke.
+# I wish the AT-SPI spec'd this out as machine readable (unlocalized)
+# names, but it's what we're stuck with (unfortunately).
 #
 setScriptMapping(re.compile(_('[\S\s]*StarOffice[\s\S]*')), "StarOffice")
+
+# Translators: see the regular expression note above.  This is for
+# OpenOffice and StarOffice.
+#
 setScriptMapping(re.compile(_('soffice.bin')), "StarOffice")
+
+# Translators: see the regular expression note above.  This is for the
+# Evolution mail application.
+#
 setScriptMapping(re.compile(_('[Ee]volution')), "Evolution")
-setScriptMapping(re.compile(_('Deer Park')), "Mozilla")
+
+# Translators: see the regular expression note above.  This is for the
+# help application (yelp).
+#
 setScriptMapping(re.compile(_('yelp')), "Mozilla")
+
+# Translators: see the regular expression note above.  This is for a
+# version of Mozilla Firefox, which chooses to create strange names
+# for itself at the drop of a hat.
+#
+setScriptMapping(re.compile(_('Deer Park')), "Mozilla")
+
+# Translators: see the regular expression note above.  This is for a
+# version of Mozilla Firefox, which chooses to create strange names
+# for itself at the drop of a hat.
+#
 setScriptMapping(re.compile(_('Bon Echo')), "Mozilla")
+
+# Translators: see the regular expression note above.  This is for a
+# version of Mozilla Firefox, which chooses to create strange names
+# for itself at the drop of a hat.
+#
 setScriptMapping(re.compile(_('Minefield')), "Mozilla")
+
+# Translators: see the regular expression note above.  This is for
+# the Thunderbird e-mail application.
+#
 setScriptMapping(re.compile(_('Mail/News')), "Thunderbird")
+
+# Translators: see the regular expression note above.  This is for
+# gnome_segv2, which calls itself bug-buddy in at-poke.
+#
 setScriptMapping(re.compile(_('bug-buddy')), "gnome_segv2")
+
+# Translators: see the regular expression note above.  This is for
+# the underlying terminal support in gnome-terminal.
+#
 setScriptMapping(re.compile(_('vte')), "gnome-terminal")
+
+# Translators: see the regular expression note above.  This is for
+# the time-admin application.
+#
 setScriptMapping(re.compile(_('time-admin')), "users-admin")
