@@ -23,10 +23,10 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 1965 2007-01-31 01:39:25Z wwalker $"
-__version__   = "$Revision: 1965 $"
-__date__      = "$Date: 2007-01-30 20:39:25 -0500 (Tue, 30 Jan 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: speechgenerator.py 2280 2007-04-11 15:54:35Z wwalker $"
+__version__   = "$Revision: 2280 $"
+__date__      = "$Date: 2007-04-11 11:54:35 -0400 (Wed, 11 Apr 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import math
@@ -36,7 +36,6 @@ import debug
 import orca_state
 import rolenames
 import settings
-import util
 
 from orca_i18n import _                          # for gettext support
 
@@ -166,7 +165,7 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken.
         """
 
-        result = util.getAcceleratorAndShortcut(obj)
+        result = self._script.getAcceleratorAndShortcut(obj)
 
         accelerator = result[0]
         #shortcut = result[1]
@@ -195,19 +194,22 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken.
         """
         if obj.state.count(atspi.Accessibility.STATE_SENSITIVE) == 0:
+            # Translators: this represents an item on the screen that has
+            # been set insensitive (or grayed out).
+            #
             return [_("grayed")]
         else:
             return []
 
     def _getSpeechForObjectLabel(self, obj):
-        label = util.getDisplayedLabel(obj)
+        label = self._script.getDisplayedLabel(obj)
         if label:
             return [label]
         else:
             return []
 
     def _getSpeechForObjectName(self, obj):
-        name = util.getDisplayedText(obj)
+        name = self._script.getDisplayedText(obj)
         if name:
             return [name]
         elif obj.description:
@@ -301,7 +303,7 @@ class SpeechGenerator:
 
         # Find all the unrelated labels in the dialog and speak them.
         #
-        labels = util.findUnrelatedLabels(obj)
+        labels = self._script.findUnrelatedLabels(obj)
         for label in labels:
             utterances.append(label.name)
 
@@ -372,8 +374,12 @@ class SpeechGenerator:
 
         utterances = []
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+            # Translators: this represents the state of a checkbox.
+            #
             checkedState = _("checked")
         else:
+            # Translators: this represents the state of a checkbox.
+            #
             checkedState = _("not checked")
 
         # If it's not already focused, say it's name
@@ -700,6 +706,9 @@ class SpeechGenerator:
                 hasItems = True
                 break
         if not hasItems:
+            # Translators: this is the number of items in a layered pane
+            # or table.
+            #
             utterances.append(_("0 items"))
 
         return utterances
@@ -815,7 +824,7 @@ class SpeechGenerator:
         if obj.role != rolenames.ROLE_PARAGRAPH:
             utterances.extend(self._getSpeechForObjectRole(obj))
 
-        [text, caretOffset, startOffset] = util.getTextLineAtCaret(obj)
+        [text, caretOffset, startOffset] = self._script.getTextLineAtCaret(obj)
         utterances.append(text)
 
         self._debugGenerator("_getSpeechForText",
@@ -898,8 +907,9 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken for the object.
         """
 
-        percentage = ("%d" % obj.value.currentValue) + " " \
-                     + _("percent") + ". "
+        # Translators: this is the percentage value of a progress bar.
+        #
+        percentage = _("%d percent.") % obj.value.currentValue + " "
 
         utterances = []
 
@@ -952,8 +962,14 @@ class SpeechGenerator:
 
         utterances = []
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+            # Translators: this is in reference to a radio button being
+            # selected or not.
+            #
             selectionState = _("selected")
         else:
+            # Translators: this is in reference to a radio button being
+            # selected or not.
+            #
             selectionState = _("not selected")
 
         # If it's not already focused, say it's name
@@ -1130,7 +1146,7 @@ class SpeechGenerator:
         """
 
         if already_focused:
-            utterances = [util.getDisplayedText(obj)]
+            utterances = [self._script.getDisplayedText(obj)]
         else:
             utterances = self._getDefaultSpeech(obj, already_focused)
 
@@ -1186,6 +1202,9 @@ class SpeechGenerator:
                 hasItems = True
                 break
         if not hasItems:
+            # Translators: this is the number of items in a layered pane
+            # or table.
+            #
             utterances.append(_("0 items"))
 
         return utterances
@@ -1220,22 +1239,33 @@ class SpeechGenerator:
                     obj.role = rolenames.ROLE_TABLE_CELL
                     break
 
-        utterances.append(util.getDisplayedText(\
-                          util.getRealActiveDescendant(obj)))
+        utterances.append(self._script.getDisplayedText(\
+                          self._script.getRealActiveDescendant(obj)))
 
         # [[[TODO: WDW - HACK attempt to determine if this is a node;
         # if so, describe its state.]]]
         #
         if obj.state.count(atspi.Accessibility.STATE_EXPANDABLE):
             if obj.state.count(atspi.Accessibility.STATE_EXPANDED):
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
                 utterances.append(_("expanded"))
             else:
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
                 utterances.append(_("collapsed"))
 
             # If this is an expandable table cell with no children, then
             # let the user know.
             #
             if obj.childCount == 0:
+                # Translators: this is the number of items in a layered pane
+                # or table.
+                #
                 utterances.append(_("0 items"))
 
         self._debugGenerator("_getSpeechForTableCell",
@@ -1350,8 +1380,11 @@ class SpeechGenerator:
         """
 
         if settings.speechVerbosityLevel == settings.VERBOSITY_LEVEL_VERBOSE:
-            utterances = [_("tear off menu item")]
+            utterances = [rolenames.getSpeechForRoleName(obj)]
         else:
+            # Translators: brief spoken words for the rolename of a tear off
+            # menu item.
+            #
             utterances = [_("tear off")]
 
         self._debugGenerator("_getSpeechForTearOffMenuItem",
@@ -1372,11 +1405,11 @@ class SpeechGenerator:
         """
 
         title = None
-        frame = util.getFrame(obj)
+        frame = self._script.getFrame(obj)
         if frame:
             title = frame.name
         if not title:
-            title = util.getDisplayedLabel(obj)
+            title = self._script.getDisplayedLabel(obj)
 
         utterances = [title]
 
@@ -1400,8 +1433,12 @@ class SpeechGenerator:
 
         utterances = []
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+            # Translators: the state of a toggle button.
+            #
             checkedState = _("pressed")
         else:
+            # Translators: the state of a toggle button.
+            #
             checkedState = _("not pressed")
 
         # If it's not already focused, say it's name
@@ -1542,17 +1579,6 @@ class SpeechGenerator:
         if obj is stopAncestor:
             return utterances
 
-        # We try to ignore fillers and panels without names.
-        # [[[TODO: WDW - HACK sometimes table cells can be children
-        # of table cells (see the "Browse" dialog of gnome-terminal
-        # via "Edit" -> "Current Profile" -> "General" Tab ->
-        # "Profile icon:" button -> "Browse..." button - each element
-        # in the list is a compound table cell where the icon and
-        # text are child table cells of the table cell).  So...
-        # we happily ignore those as well.  One thing we might
-        # want to do is treat the parent as a compound object.
-        # Logged as bugzilla bug 319751.]]]
-        #
         parent = obj.parent
         if parent \
             and (obj.role == rolenames.ROLE_TABLE_CELL) \
@@ -1562,45 +1588,21 @@ class SpeechGenerator:
         while parent and (parent.parent != parent):
             if parent == stopAncestor:
                 break
-            if (parent.role != rolenames.ROLE_FILLER) \
-                and (parent.role != rolenames.ROLE_SECTION) \
-                and (parent.role != rolenames.ROLE_LAYERED_PANE) \
-                and (parent.role != rolenames.ROLE_SPLIT_PANE) \
-                and (parent.role != rolenames.ROLE_SCROLL_PANE) \
-                and (parent.role != rolenames.ROLE_UNKNOWN) \
-                and (not self._script.isLayoutOnly(parent)):
-
-                # Announce the label and text of the object in the hierarchy.
-                #
-                text = util.getDisplayedText(parent)
-                label = util.getDisplayedLabel(parent)
-
-                # Push announcement of cell after text and label.
-                #
-                if parent.role != rolenames.ROLE_TABLE_CELL:
-                    utterances.append(rolenames.getSpeechForRoleName(parent))
-
-                if text and len(text):
+            if not self._script.isLayoutOnly(parent):
+                text = self._script.getDisplayedLabel(parent)
+                if not text and parent.text:
+                    text = self._script.getDisplayedText(parent)
+                if text and len(text.strip()):
+                    # Push announcement of cell to the end
+                    #
+                    if not parent.role in [rolenames.ROLE_TABLE_CELL,
+                                           rolenames.ROLE_FILLER]:
+                        utterances.append(\
+                            rolenames.getSpeechForRoleName(parent))
                     utterances.append(text)
-                if label and len(label):
-                    utterances.append(label)
-
-                if parent.role == rolenames.ROLE_TABLE_CELL:
-                    utterances.append(rolenames.getSpeechForRoleName(parent))
-
-            # [[[TODO: HACK - we've discovered oddness in hierarchies
-            # such as the gedit Edit->Preferences dialog.  In this
-            # dialog, we have labeled groupings of objects.  The
-            # grouping is done via a FILLER with two children - one
-            # child is the overall label, and the other is the
-            # container for the grouped objects.  When we detect this,
-            # we add the label to the overall context.]]]
-            #
-            if parent.role == rolenames.ROLE_FILLER:
-                label = util.getDisplayedLabel(parent)
-                if label and len (label):
-                    utterances.append(label)
-
+                    if parent.role == rolenames.ROLE_TABLE_CELL:
+                        utterances.append(\
+                            rolenames.getSpeechForRoleName(parent))
             parent = parent.parent
 
         utterances.reverse()
